*******
Credits
*******

Tektronix Oscilloscope is developed by `Bruno Mecke`_ (Github: `BMecke`_).

.. _Bruno Mecke: https://bmecke.de/
.. _BMecke: https://github.com/bmecke/


Development Lead
================

* Bruno Mecke <info@bmecke.de>


Contributors
============

* Leander Claes
* Kevin Koch
* Hanna Schmiegel
